Coverage for appr/api/config.py: 100%

# Coverage for appr/api/config.py : 100%

## 11 statements 11 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 | from __future__ import absolute_import, division, print_function import os class Config(object): """ Default configuration """ DEBUG = False APPR_URI = os.getenv('APPR_URI', "http://localhost:5000") class ProductionConfig(Config): """ Production configuration """ APPR_URI = "http://localhost:5000" APPR_BACKEND = 'false' class DevelopmentConfig(Config): """ Development configuration """ DEBUG = True # APPR_URI = 'https://api.appr.sh' APPR_URI = os.getenv('APPR_URI', "http://localhost:5000")